# pyLife addons

Additional packages to use with pyLife.

Here we are collecting packages that can be installed along with pyLife for
supporting tasks.  They are not part of the `pylife` package mostly for
technical reasons.  Yet, their sourcecode resides in the same repository in
order to make sure that their versions are corresponding to the one of pyLife.

## Available addon packages

* <a href="odbclient">`pylife-odbclient`</a> – a client-server solution to read access Abaqus
  `.odb` files from within a Python 3.x process.
* <a href="odbserver">`pylife-odbserver`</a> – the server part for `pylife-odbclient`
